@@ -15,10 +15,11 @@ from debian_linux.abi import Symbols
 from debian_linux.config import *
 from debian_linux.debian import *
 
-default_url_base = "http://deb.debian.org/debian/"
-default_url_base_incoming = "http://incoming.debian.org/debian-buildd/"
-default_url_base_ports = "http://ftp.ports.debian.org/debian-ports/"
-default_url_base_ports_incoming = "http://incoming.ports.debian.org/"
+default_url_base = "https://deb.debian.org/debian/"
+default_url_base_incoming = "https://incoming.debian.org/debian-buildd/"
+default_url_base_ports = "https://deb.debian.org/debian-ports/"
+default_url_base_ports_incoming = "https://incoming.ports.debian.org/"
+default_url_base_security = "https://deb.debian.org/debian-security/"
 
 
 class url_debian_flat(object):
@@ -44,6 +45,11 @@ class url_debian_ports_pool(url_debian_pool):
         return self.base + "pool-" + arch + "/main/" + source[0] + "/" + source + "/" + filename
 
 
+class url_debian_security_pool(url_debian_pool):
+    def __call__(self, source, filename, arch):
+        return self.base + "pool/updates/main/" + source[0] + "/" + source + "/" + filename
+
+
 class Main(object):
     dir = None
 
@@ -182,10 +188,12 @@ if __name__ == '__main__':
     options.add_option("-i", "--incoming", action="store_true", dest="incoming")
     options.add_option("--incoming-config", action="store_true", dest="incoming_config")
     options.add_option("--ports", action="store_true", dest="ports")
+    options.add_option("--security", action="store_true", dest="security")
     options.add_option("-u", "--url-base", dest="url_base", default=default_url_base)
     options.add_option("--url-base-incoming", dest="url_base_incoming", default=default_url_base_incoming)
     options.add_option("--url-base-ports", dest="url_base_ports", default=default_url_base_ports)
     options.add_option("--url-base-ports-incoming", dest="url_base_ports_incoming", default=default_url_base_ports_incoming)
+    options.add_option("--url-base-security", dest="url_base_security", default=default_url_base_security)
 
     opts, args = options.parse_args()
 
@@ -201,11 +209,14 @@ if __name__ == '__main__':
     url_base_incoming = url_debian_pool(opts.url_base_incoming)
     url_base_ports = url_debian_ports_pool(opts.url_base_ports)
     url_base_ports_incoming = url_debian_flat(opts.url_base_ports_incoming)
+    url_base_security = url_debian_security_pool(opts.url_base_security)
     if opts.incoming_config:
         url = url_config = url_base_incoming
     else:
         url_config = url_base
-        if opts.ports:
+        if opts.security:
+            url = url_base_security
+        elif opts.ports:
             url = url_base_ports_incoming if opts.incoming else url_base_ports
         else:
             url = url_base_incoming if opts.incoming else url_base
